@@ -8,7 +8,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION          = '0.15';
+our $VERSION          = '0.16';
 our @CANNED_RESPONSES = ();
 
 use LWP::UserAgent;
@@ -122,12 +122,10 @@ sub request {
     my $res  = $resp_class->new();
 
     my $url  = URI->new($self->intl_url($request->amzn_xml_url()));
-    my $page = 0;
+    my $page = $request->{page};
     my $ref;
 
     {
-        $page++;
-
         my %params = $request->params();
         $params{page}   = $page;
         $params{locale} = $self->{locale} if exists $self->{locale};
@@ -194,12 +192,14 @@ sub request {
           ) {
             $AMZN_WISHLIST_BUG_ENCOUNTERED = 1;
             DEBUG("Trying to fetch additional wishlist page (AMZN bug)");
+            $page++;
             redo;
         }
 
         if(exists $ref->{TotalPages} and
            $ref->{TotalPages} > $page) {
             DEBUG("Page $page of $ref->{TotalPages} fetched - continuing");
+            $page++;
             redo;
         }
 
@@ -800,6 +800,64 @@ and if it works, I'll accept it and will work it into the main distribution.
 Your name will show up in the contributor's list below (unless you tell
 me otherwise).
 
+=head2 SAMPLE SCRIPTS
+
+There's a number of useful scripts in the distribution's eg/ directory.
+Take C<power> for example, written by Martin Streicher 
+E<lt>martin.streicher@apress.comE<gt>: I lets you perform 
+a I<power search> using Amazon's query language. To search for all books 
+written by Randal Schwartz about Perl, call this from the command line:
+
+    power 'author: schwartz subject: perl'
+
+Note that you need to quote the query string to pass it as one argument
+to C<power>. If a power search returns more results than you want to
+process at a time, just limit the number of pages, telling C<power>
+which page to start at (C<-s>) and which one to finish with (C<-f>).
+Here's a search for all books on the subject C<computer>, limited
+to the first 10 pages:
+
+    power -s 1 -f 10 'subject: computer'
+
+Check out the script C<power> in eg/ for more options.
+
+=head2 HOW TO SEND ME PATCHES
+
+If you want me to include your modification or enhancement 
+in the distribution of Net::Amazon, please do the following:
+
+=over 4
+
+=item *
+
+Work off the latest CVS version. Here's the steps to get it:
+
+    CVSROOT=:pserver:anonymous@cvs.net-amazon.sourceforge.net:/cvsroot/net-amazon
+    export CVSROOT
+    cvs login (just hit Enter)
+    cvs co Net-Amazon
+
+This will create a new C<Net-Amazon> directory with the latest 
+development version of C<Net::Amazon> on your local machine.
+
+=item *
+
+Apply your changes to this development tree.
+
+=item *
+
+Run a diff between the tree and your changes it in this way:
+
+    cd Net-Amazon
+    cvs diff -Nau >patch_to_mike.txt
+
+=item *
+
+Email me C<patch_to_mike.txt>. If your patch works (and you've included
+test cases and documentation), I'll apply it on the spot.
+
+=back
+
 =head1 INSTALLATION
 
 C<Net::Amazon> depends on Log::Log4perl, which can be pulled from CPAN by
